@@ -167,10 +167,10 @@ class OOF(object):
             self.set_estimator_predict(estimator)  # 设定predic方法
             self._estimators.append(estimator)
 
-            valid_predict, test_predict = map(estimator.predict, (X[valid_index_], X_test))  # 避免 X 预测值缺损
+            valid_predict, test_predict = map(estimator.predict, (X[valid_index], X_test))
             ##############################################################
 
-            self.oof_train_proba[valid_index] = valid_predict
+            self.oof_train_proba[valid_index] = estimator.predict(X[valid_index_])  # 避免 X 预测值缺损
             self.oof_test_proba += test_predict / cv
 
             # 记录特征重要性
